﻿using System;
using System.Windows;
using System.Windows.Navigation;
using GalaSoft.MvvmLight.Ioc;
using GalaSoft.MvvmLight.Messaging;
using RssReader.Helpers;
using RssReader.ViewModel;

namespace RssReader
{
    public partial class MainPage : IDialogService
    {
        public MainPage()
        {
            InitializeComponent();
        }

        public void ShowError(string errorMessage, string title, string buttonText)
        {
            MessageBox.Show(errorMessage, title, MessageBoxButton.OK);
        }

        public void ShowError(Exception error, string title, string buttonText)
        {
            MessageBox.Show(error.Message, title, MessageBoxButton.OK);
        }

        public void ShowMessage(string message, string title, string buttonText)
        {
            // In Windows Phone, there is no way to set the text of the button
            // in a MessageBox. In a real life production app, never use a MessageBox
            // to show messages, instead implement a custom message box, for example
            // as a UserControl similar to the StatusControl shown in this example.
            MessageBox.Show(message, title, MessageBoxButton.OK);
        }

        protected override void OnNavigatedFrom(NavigationEventArgs e)
        {
            Messenger.Default.Unregister<StatusMessage>(
                this, HandleStatusMessage);

            SimpleIoc.Default.Unregister<IDialogService>();

            base.OnNavigatedFrom(e);
        }

        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            Messenger.Default.Register<StatusMessage>(
                this, HandleStatusMessage);

            SimpleIoc.Default.Register<IDialogService>(() => this);

            base.OnNavigatedTo(e);
        }

        private void HandleStatusMessage(StatusMessage msg)
        {
            Status.Message = msg.Status;
            Status.Show(msg.TimeoutMilliseconds);
        }

        private void RefreshClick(object sender, EventArgs e)
        {
            var vm = (MainViewModel)DataContext;
            vm.RefreshCommand.Execute(null);
        }
    }
}