﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Threading.Tasks;
using System.Xml.Linq;

namespace RssReader.Model
{
    public class RssService : IRssService
    {
        private const string NewsPageUrl = "http://rss.cnn.com/rss/edition.rss";

        public async Task<IList<RssArticle>> GetArticles()
        {
            var downloader = new Downloader();

            var feed = await downloader.GetRssFeed(NewsPageUrl);

            var reader = new StringReader(feed);
            var document = XDocument.Load(reader);

            // Assume that feed is always well formed

            var list = document
                .Element("rss")
                .Element("channel")
                .Descendants("item")
                .Select(
                    itemXml => new RssArticle
                    {
                        Link = new Uri(itemXml.Element("link").Value),
                        Title = itemXml.Element("title").Value,
                        Summary = itemXml.Element("description").Value
                    })
                .ToList();

            return list;
        }
    }
}