﻿using System.Threading.Tasks;
using System.Windows;

#if NETFX_CORE
using Windows.UI.Xaml;
#endif

namespace RssReader
{
    public partial class StatusControl
    {
        /// <summary>
        /// The <see cref="Message" /> dependency property's name.
        /// </summary>
        public const string MessagePropertyName = "Message";

        /// <summary>
        /// Identifies the <see cref="Message" /> dependency property.
        /// </summary>
        public static readonly DependencyProperty MessageProperty = DependencyProperty.Register(
            MessagePropertyName,
            typeof(string),
            typeof(StatusControl),
            new PropertyMetadata(string.Empty));

        /// <summary>
        /// Gets or sets the value of the <see cref="Message" />
        /// property. This is a dependency property.
        /// </summary>
        public string Message
        {
            get
            {
                return (string)GetValue(MessageProperty);
            }
            set
            {
                SetValue(MessageProperty, value);
            }
        }

        public StatusControl()
        {
            InitializeComponent();
        }

        public void Hide()
        {
            Visibility = Visibility.Collapsed;
        }

        public async void Show(int timeout = 0)
        {
            Visibility = Visibility.Visible;

            if (timeout > 0)
            {
                await Task.Delay(timeout);
                Visibility = Visibility.Collapsed;
            }
        }
    }
}