﻿using System;
using System.Collections.Generic;
using System.Threading.Tasks;
using GalaSoft.MvvmLight.Ioc;
using GalaSoft.MvvmLight.Messaging;
using Microsoft.VisualStudio.TestPlatform.UnitTestFramework;
using RssReader.Helpers;
using RssReader.Model;
using RssReader.ViewModel;

namespace RssReader.Win8.Test
{
    [TestClass]
    public class MainViewModelTest
    {
        [TestMethod]
        public void TestSendingErrorMessages()
        {
            var vm = new MainViewModel(
                new TestRssService(),
                new TestNavigationService());

            StatusMessage receivedMessage = null;

            Messenger.Default.Register<StatusMessage>(
                this,
                m => receivedMessage = m);

            var dialogService = new TestDialogService();

            SimpleIoc.Default.Register<IDialogService>(() => dialogService);

            vm.Refresh();

            // Test that a status message was sent
            Assert.IsNotNull(receivedMessage);

            Assert.AreEqual(dialogService.MessageReceived, TestRssService.TestErrorMessage);
        }

        public class TestDialogService : IDialogService
        {
            public string MessageReceived
            {
                get;
                private set;
            }

            public void ShowError(string errorMessage, string title, string buttonText)
            {
                MessageReceived = errorMessage;
            }

            public void ShowError(Exception error, string title, string buttonText)
            {
                MessageReceived = error.Message;
            }

            public void ShowMessage(string message, string title, string buttonText)
            {
                MessageReceived = message;
            }
        }

        public class TestNavigationService : INavigationService
        {
            public void GoBack()
            {
            }

            public void NavigateTo(Type pageType)
            {
            }

            public void NavigateTo(Type sourcePageType, object parameter)
            {
            }
        }

        public class TestRssService : IRssService
        {
            public const string TestErrorMessage = "This is a test error only";
            public const int Timeout = 1234;

            public Task<IList<RssArticle>> GetArticles()
            {
                throw new InvalidOperationException(TestErrorMessage);
            }
        }
    }
}