﻿using System;
using GalaSoft.MvvmLight.Ioc;
using GalaSoft.MvvmLight.Messaging;
using RssReader.Helpers;
using RssReader.Model;
using RssReader.ViewModel;
using Windows.UI.Popups;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Navigation;

namespace RssReader
{
    public sealed partial class MainPage : IDialogService
    {
        public MainPage()
        {
            InitializeComponent();
        }

        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            Messenger.Default.Register<StatusMessage>(
                this, HandleStatusMessage);

            SimpleIoc.Default.Register<IDialogService>(() => this);

            base.OnNavigatedTo(e);
        }

        protected override void OnNavigatedFrom(NavigationEventArgs e)
        {
            Messenger.Default.Unregister<StatusMessage>(
                this, HandleStatusMessage);

            SimpleIoc.Default.Unregister<IDialogService>();

            base.OnNavigatedFrom(e);
        }

        private void HandleStatusMessage(StatusMessage msg)
        {
            Status.Message = msg.Status;
            Status.Show(msg.TimeoutMilliseconds);
        }

        private void RssArticleTapped(object sender, TappedRoutedEventArgs e)
        {
            // This code is used to trigger the command even though
            // Blend Behaviors (and thus EventToCommand) are not available
            // for Windows 8.

            var element = (FrameworkElement)sender;
            var item = element.DataContext as RssArticle;

            if (item != null)
            {
                var vm = (MainViewModel)DataContext;
                vm.NavigateToArticleCommand.Execute(item);
            }
        }

        // IDialogService implementation

        public async void ShowMessage(string message, string title, string buttonText)
        {
            // Using the same MessageDialog for errors and messages.
            // In a real life production implementation, a custom
            // dialog box would be designed, and these methods would probably
            // be passed into a Page base class (for instance in 
            // the LayoutAwarePage class in the Common folder.
            var dialog = new MessageDialog(message, title);

            dialog.Commands.Add(new UICommand(buttonText));

            dialog.CancelCommandIndex = 0;
            await dialog.ShowAsync();
        }

        public void ShowError(string errorMessage, string title, string buttonText)
        {
            // Using the same MessageDialog for errors and normal messages. 
            ShowMessage(errorMessage, title, buttonText);
        }

        public void ShowError(Exception error, string title, string buttonText)
        {
            ShowMessage(error.Message, title, buttonText);
        }
    }
}